function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

/* eslint-env node */

var fetch = require('node-fetch');
var fullCalendarEventsToIcs = require('./fullcalendar-to-ics.js');

function setHeaders(res) {
	res.setHeader('Expires', 'Mon, 01 Jan 1990 00:00:00 GMT');
	res.setHeader('Date', new Date().toGMTString());
	res.setHeader('Content-Type', 'text/calendar; charset=UTF-8');
	res.setHeader('Cache-Control', 'no-cache, no-store, max-age=0, must-revalidate');
	res.setHeader('Pragma', 'no-cache');
}

function getIcalsFromUrls(urls) {
	var promises = [];
	var _iteratorNormalCompletion = true;
	var _didIteratorError = false;
	var _iteratorError = undefined;

	try {
		var _loop = function _loop() {
			var url = _step.value;

			promises.push(fetch(url).then(function (response) {
				return response.text();
			}).catch(function (err) {
				console.error('Error reading ' + url + ': ' + err);
				return err;
			}));
		};

		for (var _iterator = urls[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
			_loop();
		}
	} catch (err) {
		_didIteratorError = true;
		_iteratorError = err;
	} finally {
		try {
			if (!_iteratorNormalCompletion && _iterator.return) {
				_iterator.return();
			}
		} finally {
			if (_didIteratorError) {
				throw _iteratorError;
			}
		}
	}

	return Promise.all(promises);
}

function getIcalsFromFullCalendarEventSourceCalendars(calendars) {
	var promises = [];
	var _iteratorNormalCompletion2 = true;
	var _didIteratorError2 = false;
	var _iteratorError2 = undefined;

	try {
		var _loop2 = function _loop2() {
			var calendar = _step2.value;

			promises.push(fetch(calendar.source).then(function (response) {
				return response.json();
			}).then(function (events) {
				return fullCalendarEventsToIcs(events, calendar);
			}).catch(function (err) {
				console.error('Error parsing calendar', err, calendar);
				return err;
			}));
		};

		for (var _iterator2 = calendars[Symbol.iterator](), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true) {
			_loop2();
		}
	} catch (err) {
		_didIteratorError2 = true;
		_iteratorError2 = err;
	} finally {
		try {
			if (!_iteratorNormalCompletion2 && _iterator2.return) {
				_iterator2.return();
			}
		} finally {
			if (_didIteratorError2) {
				throw _iteratorError2;
			}
		}
	}

	return Promise.all(promises);
}

function isCalendarVisible(calendar, keys) {
	if (!Array.isArray(keys)) keys = [keys];

	return calendar && (!calendar.private || Boolean(calendar.key) && typeof calendar.key === 'string' && keys.includes(calendar.key));
}

function getDeepCalendarIdsFromSubGroups(calendarGroup, allCalendars, allCalendarGroups) {
	var calendarIds = [];

	if (calendarGroup.calendars && calendarGroup.calendars.length > 0) {
		calendarIds.push.apply(calendarIds, _toConsumableArray(calendarGroup.calendars));
	}

	if (calendarGroup.subGroups && calendarGroup.subGroups.length > 0) {
		var subGroups = calendarGroup.subGroups.map(function (id) {
			return allCalendarGroups[id];
		});
		var _iteratorNormalCompletion3 = true;
		var _didIteratorError3 = false;
		var _iteratorError3 = undefined;

		try {
			for (var _iterator3 = subGroups[Symbol.iterator](), _step3; !(_iteratorNormalCompletion3 = (_step3 = _iterator3.next()).done); _iteratorNormalCompletion3 = true) {
				var subGroup = _step3.value;

				calendarIds.push.apply(calendarIds, _toConsumableArray(getDeepCalendarIdsFromSubGroups(subGroup, allCalendars, allCalendarGroups)));
			}
		} catch (err) {
			_didIteratorError3 = true;
			_iteratorError3 = err;
		} finally {
			try {
				if (!_iteratorNormalCompletion3 && _iterator3.return) {
					_iterator3.return();
				}
			} finally {
				if (_didIteratorError3) {
					throw _iteratorError3;
				}
			}
		}
	}

	return calendarIds;
}

module.exports = {
	setHeaders: setHeaders,
	getIcalsFromUrls: getIcalsFromUrls,
	getIcalsFromFullCalendarEventSourceCalendars: getIcalsFromFullCalendarEventSourceCalendars,
	isCalendarVisible: isCalendarVisible,
	getDeepCalendarIdsFromSubGroups: getDeepCalendarIdsFromSubGroups
};
